module SPos (nocc,noccFromBool,sposConstructor,posArgs) where

import Abstract
import Value
import TCM
import Eval
-- import CallStack
import TraceError

import Control.Monad.Identity
import Control.Monad.Reader
import Control.Monad.State
import Control.Monad.Error

import Debug.Trace

--------------------

-- nocc (used by SPos and TypeCheck)
-- check that a does not occur in tv
-- a may be a "atomic value" i.e not pi , lam , app , or succ 
nocc :: Int -> Val -> TVal -> TypeCheck Bool
nocc k a tv = -- trace ("noccRecArg " ++ show tv) 
     case tv of
         VPi dec x av env b -> 
             do no <- nocc k a av
                case no of 
                  True -> do
                      bv <- whnf (update env x (VGen k)) b
                      nocc (k+1) a bv
                  False  -> return False
         VLam x env b -> do
                 bv <- whnf (update env x (VGen k)) b
                 nocc (k+1) a bv
         VSucc v -> nocc k a v
         VApp v1 vl -> do n <- nocc k a v1
                          nl <- mapM (nocc k a) vl
                          return $ n && and nl
         _ -> return $ a /= tv

noccFromBool :: Bool -> Pos
noccFromBool True  = NOcc
noccFromBool False = NSPos


-----------------------------------
-- check that recursive data argument n and the spos declared parameter variables are only used strictly positvly
-- return True if it has a recursive argument at all
sposConstructor :: Name -> Int -> [Pos] -> TVal -> TypeCheck Bool
sposConstructor n k sp tv = loop k tv NOcc where 
  loop k tv isRec 
   = case tv of
         VPi dec x av env b -> do 
              spr <- spos 0 (VDef n) av
              spv <- sposVals (posGen 0 sp) av
              case (isSPos spr,isSPos spv) of
                (True,True) -> do bv <- whnf (update env x (VGen k)) b
                                  loop (k+1) bv (isRec `polAnd` spr `polAnd` spv)
                (False,_) -> throwErrorMsg "rec. arg not strictly positive"
                (True,False) -> throwErrorMsg "parameter not strictly positive"
         _ -> return (isRec /= NOcc)

sposVals :: [Val] -> TVal -> TypeCheck Pos
sposVals vals tv = do sl <- mapM (\i -> spos 0 i tv) vals
                      return $ foldl polAnd NOcc sl

posGen :: Int -> [Pos] -> [Val]
posGen i [] = []
posGen i (p:pl) = case p of
                    SPos -> (VGen i) : (posGen (i+1) pl)
                    NSPos -> posGen (i+1) pl

posArgs :: [Val] -> [Pos] -> ([Val],[Val])
posArgs vl pl = let l = zip vl pl
                    l1 = [ v | (v,SPos) <- l]
                    l2 = [ v | (v,NSPos) <- l]
                 in
                   (l1,l2)

-- check that a only occurs strictly pos tv
-- a may be a "atomic value" ie not pi , lam , app , or succ
-- Results are: SPos, NSPos, or NOcc 
spos :: Int -> Val -> TVal -> TypeCheck Pos
spos k a tv = -- trace ("spos " ++ show tv) 
     case tv of
         VPi dec x av env b -> 
             do no <- nocc k a av
                case no of 
                  True -> do
                      bv <- whnf (update env x (VGen k)) b
                      spos (k+1) a bv
                  False  -> return NSPos
         VLam x env b -> do
                 bv <- whnf (update env x (VGen k)) b
                 spos (k+1) a bv
         VSucc v -> spos k a v
         VApp (VDef m) vl -> do 
               sig <- gets signature
               case (lookupSig m sig) of
                 (DataSig { numPars = p, positivity = pos }) ->
                     do let (pparams,nparams) = posArgs vl pos
                        let rest = drop p vl
                        sl <- mapM (spos k a) pparams
                        nl <- mapM (nocc k a) (nparams ++ rest)
                        mp <- spos k a (VDef m)
                        return $ foldl polAnd (noccFromBool $ and nl) (mp:sl)
                 _ -> do nl <- mapM (nocc k a) vl
                         return $ noccFromBool $ and nl
{- Superfluous clause
         VApp v1 vl -> do n <- nocc k a v1
                          nl <- mapM (nocc k a) vl
                          return $ noccFromBool $ n && and nl
 -}
         a' | a == a' -> return SPos
         _ -> nocc k a tv >>= return . noccFromBool

