{-# OPTIONS -XPatternGuards #-}

module TypeChecker where

import Util

import Abstract
import Value
import TCM
import Eval
import SPos
-- import CallStack
import TraceError

import Warshall -- size constraint checking

import Termination

import Completness

import Data.Map (Map)
import qualified Data.Map as Map

import Control.Monad.Identity
import Control.Monad.State
import Control.Monad.Error
import Control.Monad.Reader

import Debug.Trace


traceCheck msg a = a -- trace msg a 
traceCheckM msg = return () -- traceM msg

{-
traceCheck msg a = trace msg a 
traceCheckM msg = traceM msg
-}
  
{- DEAD CODE
runWhnf :: Signature -> TypeCheck a -> IO (Either TraceError (a,Signature))
runWhnf sig tc = (runErrorT (runStateT tc  sig)) 
-} 

doWhnf sig v = runErrorT (runReaderT (runStateT (whnf [] v) (TCState sig emptyConstraints)) emptyContext)
-- doWhnf sig v = runCallStackT (runReaderT (runStateT (whnf [] v) (TCState sig emptyConstraints)) emptyContext) []

-- top-level functions -------------------------------------------

runTypeCheck :: TCState -> TypeCheck a -> IO (Either TraceError (a,TCState))
runTypeCheck st tc = runErrorT (runReaderT (runStateT tc st) emptyContext) 
-- runTypeCheck st tc = runCallStackT (runReaderT (runStateT tc st) emptyContext) []
 
typeCheck dl = runTypeCheck initSt (typeCheckDecls dl)

-- checking top-level declarations -------------------------------

echo :: MonadIO m => String -> m ()
echo = liftIO . putStrLn

echoTySig :: MonadIO m => Name -> Expr -> m ()
echoTySig n t = echo $ n ++ " : " ++ show t

typeCheckDecls :: [Declaration] -> TypeCheck ()
typeCheckDecls [] = return ()
typeCheckDecls (d:ds) = do typeCheckDeclaration d
                           typeCheckDecls ds
                           return ()

typeCheckDeclaration :: Declaration -> TypeCheck ()
typeCheckDeclaration (DataDecl n sz co pos tel t cs) = enter n $
 (do sig <- gets signature
     let dt = (teleToType tel t)
     echoTySig n dt
     let params = length tel
     let p' = case sz of
                Sized -> params + 1
                NotSized -> params
     checkDataType p' dt
     v <- whnf [] dt
     let cis = map (analyzeConstructor co tel) cs
     addSig n (DataSig { numPars = params 
                       , positivity = pos 
                       , isSized = sz
                       , isCo = co
                       , symbTyp = v
                       , constructors = cis
                       , etaExpand = False
-- if cs==[] then Just [] else Nothing
{- OLD CODE
                       , constructors = map namePart cs
                       -- at first, do not add destructors, get them out later
                       , destructors  = Nothing
                       , isFamily = t /= Set  -- currently UNUSED
 -}
                       })
     when (sz == Sized) $
           szType params v

     isRecList <- mapM (typeCheckConstructor n sz co pos tel) cs
     -- check if patterns overlaps with any other
     let overlapList = zipWith (\ ci n -> any (overlaps (corePat ci)) $ map corePat $ take n cis ++ drop (n+1) cis) cis [0..] -- worst case quadratic, could be improved by exploiting symmetry

     -- find out which of the constructors are non-overlapping
     -- add destructors only for these
     let mkDestr fi = 
          case (fClass fi) of
                     Field (Just (ty, cl)) -> 
                       [FunDecl Ind [(TypeSig (fName fi) ty,[cl])]]  
                     _ -> []
     -- cEtaExp = True means that all field names are present
     let mkDestrs ci False | cEtaExp ci = concat $ map mkDestr (cFields ci)
         mkDestrs ci _ = []
     let decls = concat $ zipWith mkDestrs cis overlapList
     mapM_ typeCheckDeclaration decls

     -- decide whether to eta-expand at this type
     -- all patterns need to be proper and non-overlapping
     -- at least one constructor needs to be eta-expandable
     let isPatIndFam = all (\ ci -> fst (cPatFam ci)) cis 
                    && not (or overlapList)
     -- do not eta-expand recursive constructors (might not terminate)
     let disableRec ci ov rec = ci { cEtaExp  
           =  cEtaExp ci        -- all destructors present
           && fst (cPatFam ci)  -- proper pattern to compute indices
           && not ov            -- non-overlapping
           && not rec }         -- non-recursive
     let cis' = zipWith3 disableRec cis overlapList isRecList
     let typeEtaExpandable = isPatIndFam && (null cis || any cEtaExp cis') 
     traceEtaM $ "data " ++ n ++ " eta-expandable " ++ show typeEtaExpandable ++ " constructors " ++ show cis'
     modifySig n (\ dataSig -> 
                      dataSig { etaExpand = typeEtaExpandable
                              , constructors = cis'
                              })

   ) -- `throwTrace` n  -- in case of an error, add name n to the trace

{- OLD CODE
{- a record type is a data type that fulfills 3 conditions
   1. non-recursive
   2. exactly 1 constructor
   3. constructor carries names for each of its arguments
 -}
     case isPatIndFam params cs of
      Just [(c,ps)] -> do 
        when (t == Set && nonRec && length cs == 1) $ do
         let constrName   = namePart (head cs) 
         let (ctel, core) = typeToTele (typePart (head cs)) 
         let destrNames = map (\ (dec,x,t) -> x) ctel
         let isRec = all (/= "") destrNames
         when isRec $ do 
  --         echo $ "+++ generating record destructors +++"
  {- now, generate destructors
  
  data Sigma (A : Set) (B : A -> Set) : Set
  {
    pair : (fst : A) -> (snd : B fst) -> Sigma A B
  }
  fst : [A : Set] -> [B : A -> Set] -> (p : Sigma A B) -> A
  { fst A B (pair .A .B _fst _snd) = _fst }
  snd : [A : Set] -> [B : A -> Set] -> (p : Sigma A B) -> B (fst p)
  { snd A B (pair .A .B _fst _snd) = _snd }
   -}      
           -- choose a name for the record to destroy
           let recName = "record_of_type_" ++ n
           let parNames = map (\ (_,x,_) -> x) tel
           -- substitute variable "fst" by application "fst A B p"
           let phi x = if x `elem` destrNames 
                         then App (Def x) (map Var (parNames ++ [recName]))
                         else Var x
           let prefix x =  "destructor_argument_" ++ x
           let pattern = ConP co constrName (map (DotP . Var) parNames 
                                          ++ map (VarP . prefix) destrNames)
           let mkDestr (_,x,t) = FunDecl Ind [(TypeSig x (teleToTypeErase tel t'),[clause])] where 
                   t' = (Pi notErased recName core . parSubst phi) t
                   clause = Clause (map VarP parNames ++ [pattern]) (Var (prefix x))
           let decls = map mkDestr ctel
           mapM_ typeCheckDeclaration decls
           modifySig n (\ dataSig -> dataSig { constructors = Just [(c,ps,destrNames)] })
         return ()
      _ -> return ()
   ) `throwTrace` n  -- in case of an error, add name n to the trace
END OLD CODE -}

typeCheckDeclaration (LetDecl _ (TypeSig n t) e ) = 
   (
    do echoTySig n t
       checkType t 
       vt <- whnf' t
       -- getEnv >>= \ rho -> traceCheckM $ "checking let-body " ++ show e ++ " : " ++ show vt ++ " in environment " ++ show rho
       checkExpr e vt
       e' <- solveAndModify e []  -- solve size constraints
       v  <- whnf' e'
       addSig n (LetSig vt v)    -- late (var -> expr) binding, but ok since no shadowing
--       addSig n (LetSig vt e')    -- late (var -> expr) binding, but ok since no shadowing
   ) `throwTrace` n

typeCheckDeclaration (FunDecl co funs) = 
  -- traceCheck ("type checking a function block") $
    typeCheckFuns co funs

{-
typeCheckConstructor :: Name -> Sized -> [Pos] -> Telescope -> Constructor -> TypeCheck ()
typeCheckConstructor d sz pos tel (TypeSig n t) = 
   ( 
   do sig <- gets signature 
      let tt = teleToTypeErase tel t
      echoTySig n tt
      let params = length tel 
      let p' = case sz of
                 Sized -> params + 1
                 NotSized -> params
      checkConType [] cxtEmpty p' tt
      let (_,target) = typeToTele tt
      checkTarget d tel target
      vt <- whnf  [] tt
      sposConstructor d 0 pos vt
      addSig n (ConSig vt)
      case sz of 
        Sized ->
            szConstructor d (length tel) vt
        NotSized -> return ()
      return ()
   ) `throwTrace` n
-}

-- returns True if constructor has recursive argument
typeCheckConstructor :: Name -> Sized -> Co -> [Pos] -> Telescope -> Constructor -> TypeCheck Bool
typeCheckConstructor d sz co pos tel (TypeSig n t) = 
   ( 
   do sig <- gets signature 
      let tt = teleToTypeErase tel t
      echoTySig n tt
      let params = length tel 
      let p' = case sz of
                 Sized -> params + 1
                 NotSized -> params
      checkConType p' tt
      let (_,target) = typeToTele tt
      checkTarget d tel target
      vt <- whnf  [] tt
      isRec <- sposConstructor d 0 pos vt
      addSig n (ConSig vt)
      case sz of 
        Sized ->
            szConstructor d co (length tel) vt
        NotSized -> return ()
      return isRec
   ) `throwTrace` n

{-
typeCheckFuns :: Co -> [(TypeSig,[Clause])] -> TypeCheck ()
typeCheckFuns co funs = do 
    mapM addFunSig funs
    mapM typeCheckFunSig funs
    -- type check and solve size constraints
    -- return clauses with meta vars resolved
    clss <- zipWithM typeCheckFunClauses [1..] funs 
    -- replace old clauses by new ones in funs
    let funs' = zipWith (\(tysig,cls) cls' -> (tysig,cl')) funs clss
    -- check sized types for admissibility
    mapM (admCheckFunSig (map (\ (TypeSig n t, cls) -> n) funs')) funs'
    liftIO $ terminationCheck funs'  
    mapM enableSig funs'      
    return ()
-}

typeCheckFuns :: Co -> [(TypeSig,[Clause])] -> TypeCheck ()
typeCheckFuns co funs = do 
    -- echo $ show funs
    mapM addFunSig funs
    mapM typeCheckFunSig funs
    -- type check and solve size constraints
    -- return clauses with meta vars resolved
    clss <- zipWithM typeCheckFunClauses [1..] funs
    -- get the list of mutually defined function names 
    let names = map (\ (TypeSig n t, cls) -> n) funs
    -- check new clauses for admissibility, inserting "unusuable" flags in the patterns where necessary
    clss <- zipWithM (\ (tysig,cls) cls' -> admCheckFunSig names tysig cls') funs clss
    -- replace old clauses by new ones in funs
    let funs' = zipWith (\(tysig,cls) cls' -> (tysig,cls')) funs clss
    terminationCheck funs'  
    mapM enableSig funs'      
    return ()

  where

    addFunSig :: (TypeSig,[Clause]) -> TypeCheck ()
    addFunSig (TypeSig n t,cl) = 
        do
          sig <- gets signature 
          vt <- whnf [] t
          addSig n (FunSig co vt cl False) --not yet type checked / termination checked

    -- admCheckFunSig mutualNames (TypeSig thisName thisType, clauses)
    admCheckFunSig :: [Name] -> TypeSig -> [Clause] -> TypeCheck [Clause] 
    admCheckFunSig mutualNames (TypeSig n t) cls = -- traceCheck ("admCheckFunSig: checking admissibility of " ++ n ++ " : " ++ show t) $  
       (
        do -- a function is not recursive if did does not mention any of the
           -- mutually defined function names
           let usedNames = rhsDefs cls
           let notRecursive = all (\ n -> not (n `elem` usedNames)) mutualNames 
           -- for non-recursive functions, we can skip the admissibility check
           if notRecursive then 
              -- trace ("function " ++ n ++ " is not recursive") $
                return cls
            else -- trace ("function " ++ n ++ " is recursive ") $ 
              do vt <- whnf [] t
                 admFunDef co cls vt
        ) `throwTrace` ("checking type of " ++ n ++ " for admissibility")
            

{-
    -- admCheckFunSig mutualNames (TypeSig thisName thisType, clauses)
    admCheckFunSig :: [Name] -> (TypeSig,[Clause]) -> TypeCheck () 
    admCheckFunSig mutualNames (TypeSig n t, cls) =   
       (
        do -- a function is not recursive if did does not mention any of the
           -- mutually defined function names
           let usedNames = rhsDefs cls
           let notRecursive = all (\ n -> not (n `elem` usedNames)) mutualNames 
           -- for non-recursive functions, we can skip the admissibility check
           when (not notRecursive) $ do
             vt <- whnf [] t
           when (not notRecursive) $ do
             vt <- whnf [] t              
             (case co of
                Ind -> do 
                   when (not (completeFun cls)) $
                      fail $ n ++ " : size pattern incomplete" 
                   let admpos = getSizeMatches cls -- admissible in which size variables?  
                   szCheckIndFun admpos vt `throwTrace` "type not admissible"

                CoInd -> do 
                   res <- admCoFun vt `throwTrace` "type not admissible"
                   case res of
                      CoFun -> return ()
                      SizedCoFun i ->
                         when (not (coFunSuccPat i cls)) $
                            fail $ n ++ " : corecursive size arguments can only be matched agains ($ i) for some size variable i"       
                )  -- TODO: this might be incorrect for mutual cofuns
        ) `throwTrace` ("type of " ++ n)
-}

    -- typeCheckFunSig (TypeSig thisName thisType, clauses)
    typeCheckFunSig :: (TypeSig,[Clause]) -> TypeCheck () 
    typeCheckFunSig (TypeSig n t, cls) =   
       (
        do echoTySig n t
           checkType t
        ) `throwTrace` ("type of " ++ n)

    typeCheckFunClauses :: Int -> (TypeSig,[Clause]) -> TypeCheck [Clause]
    typeCheckFunClauses k (TypeSig n t,cl) =
       (do cl' <- checkFun t cl
           -- traceCheck (show (TypeSig n t)) $
            -- traceCheck (show cl') $
           return cl'
       ) `throwTrace` n         

    enableSig :: (TypeSig,[Clause]) -> TypeCheck ()
    enableSig (TypeSig n _,cl') = do 
                    sig <- gets signature 
                    let (FunSig co vt cl _) = lookupSig n sig 
                    addSig n (FunSig co vt cl' True)
                    -- add a let binding for external use
                    v <- up (VDef n) vt
                    addSig (mkExtName n) (LetSig vt v)


{-
checkConType :: Env -> SemCxt -> Int -> Expr -> TypeCheck ()
checkConType rho delta p e =
    case e of
      Pi dec x t1 t2 -> do
             case (len delta) < p of
               True ->
                   return ()
               False ->
                   checkSType rho delta t1
             v_t1 <- whnf rho t1
             let (k, delta') = cxtPush (Dec False) v_t1 delta
             checkConType (update rho x (VGen k)) (delta') p t2
      _ -> checkExpr rho delta e VSet
 -}

-- check that arguments are stypes
-- check that result is a set 
--  ( params were already checked by checkDataType ) 
checkConType :: Int -> Expr -> TypeCheck ()
checkConType p e = 
    case e of
      Pi dec x t1 t2 -> do
             l <- getLen
             when (l >= p) $ checkSType t1
             addBind x (Dec False) t1 $
               checkConType p t2 
      _ -> checkSType e 
       

-- check that the data type and the parameter arguments (written down like declared in telescope) 
checkTarget :: Name -> Telescope -> Type -> TypeCheck()
checkTarget d tel tg =  case tg of
                           (App (Def n) al) -> if n == d then
                                                   do let pn = length tel
                                                      let params = take pn al
                                                      checkPs tel params -- check parameters              
                                               else throwErrorMsg $ "target mismatch " ++ show tg
                           (Def n) -> if n == d && (null tel) then return () 
                                      else throwErrorMsg $ "target mismatch" ++ show tg
                         
                           _ -> throwErrorMsg $ "target mismatch"  ++ show tg
    where checkPs :: Telescope -> [Expr] -> TypeCheck ()
          checkPs [] [] = return ()
          checkPs ((dec,n,t):tl) ((Var n'):el) = if n == n' then
                                                       checkPs tl el
                                                   else
                                                       throwErrorMsg "target param mismatch"
          checkPs _ _ = throwErrorMsg "target param mismatch"


{-
checkDataType :: Env -> SemCxt -> Int -> Expr -> TypeCheck()
checkDataType rho delta p e = 
  case e of
     Pi dec x t1 t2 -> do 
             let k = len delta
             case k < p of
               True -> 
                        checkType rho delta t1
               False ->
                        checkSType rho delta t1    
             v_t1 <- whnf rho t1 
             checkDataType (update rho x (VGen k)) (cxtPush' dec v_t1 delta) p t2  
     Set -> return ()
     _ -> throwErrorMsg "doesn't target Set"
-}                      
-- check that params are types
-- check that arguments are stypes
-- check that target is set
checkDataType :: Int -> Expr -> TypeCheck()
checkDataType p e = 
  case e of
     Pi dec x t1 t2 -> do 
             k <- getLen
             if k < p then checkType t1 else checkSType t1    
             addBind x dec t1 $
               checkDataType p t2  
     Set -> return ()
     _ -> throwErrorMsg "doesn't target Set"
                      

    
-- type checking

-- entry point 1: possibly resurrects
checkExpr :: Expr -> TVal -> TypeCheck ()
checkExpr e v = maybeResurrect v $ checkExpr' e v  -- ignore erasure

maybeResurrect :: TVal -> TypeCheck a -> TypeCheck a
maybeResurrect v = if v == VSet || v == VSize then resurrect else id

-- entry point 2: possibly resurrects
checkExprDec :: Dec -> Expr -> TVal -> TypeCheck ()
checkExprDec dec e v = maybeResurrectDec dec v $ checkExpr' e v  -- ignore erasure

maybeResurrectDec :: Dec -> TVal -> TypeCheck a -> TypeCheck a
maybeResurrectDec dec v = if erased dec || v == VSet || v == VSize then resurrect else id

checkExpr' :: Expr -> TVal -> TypeCheck ()
checkExpr' e v = do
  l <- getLen
  enter ("checkExpr' " ++ show l ++ " |- " ++ show e ++ " : " ++ show v) $ do
{-
   ask >>= \ ce -> traceCheckM ("checkExpr': " ++ show (renaming ce) ++ ";" ++ show (context ce) ++ " |- " ++ show e ++ " : " ++ show v ++ " in env" ++ show (environ ce)) $ do
-}  
    (case (e,v) of

      -- metavariables must have type size
      (Meta i, VSize) -> do 
         l <- getLen 
         addMeta l i

{- In the presence of full bracket types, 
   we could implement the following "resurrecting version of let"

   Gamma |- s : [A]   
   Gamma, x:A |- t : C   Gamma, x:A, y:A |- t = t[y/x] : C
   -------------------------------------------------------
   Gamma |- let x:[A] = s in t : C

 -}

      (LLet n t1 e1 e2,_) ->
          do 
            checkType t1
            v_t1 <- whnf' t1
            checkExpr' e1 v_t1
            new' n (Domain v_t1 (Dec False)) $
              checkExpr' e2 v  
-- Dependent let: not checkable in rho;Delta style
--            v_e1 <- whnf rho e1
--            checkExpr' (update rho n v_e1) (v_t1 : delta) e2 v  

      (Case e cs, _) -> do
          tv <- inferExpr e
          ve <- whnf' e
          cl <- checkCases ve (arrow tv v) cs
          return ()

{- Following Awodey/Bauer 2001, the following rule is valid

   Gamma, x:A |- t : B    Gamma, x:A, y:A |- t = t[y/x] : B 
   --------------------------------------------------------
   Gamma |- \xt : Pi x:[A]. B

 -}   
      (Lam y e1, VPi dec x va env t1) -> do
          rho <- getEnv  -- get the environment corresponding to Gamma
          new y (Domain va (resurrectDec dec)) $ \ vy -> do
            v_t1 <- whnf (update env x vy) t1
            -- traceCheckM $ "checking " ++ show e1 ++ " : " ++ show v_t1 
            checkExpr' e1 v_t1  
            when (erased dec) $ do  -- now check invariance of the e1 
              new y (Domain va (resurrectDec dec)) $ \ vy' -> do
                ve  <- whnf (update rho y vy)  e1 
                ve' <- whnf (update rho y vy') e1
                eqVal v_t1 ve ve'  -- BUT: ve' does not have type v_t1 !? 

-- ignore erasure in types
      (Pi dec n t1 t2,VSet) ->
          do checkExpr' t1 VSet
             addBind n dec t1 $
               checkExpr' t2 VSet

      (Succ e2,VSize) -> checkExpr' e2 VSize

      _ -> do v2 <- inferExpr e
              checkSubtype e v2 v
      ) -- >> (trace ("checkExpr successful: " ++ show e ++ ":" ++ show v) $ return ())

-- checkSubtype  expr : infered_type <= ascribed_type
checkSubtype :: Expr -> TVal -> TVal -> TypeCheck ()
checkSubtype e v2 v = do
    rho <- getEnv
    -- traceCheckM $ "computing singleton <" ++ show e ++ " : " ++ show v2 ++ "> in environment " ++ show rho
    v2principal <- sing rho e v2
    -- traceCheckM $ "subtype checking " ++ show v2principal ++ " ?<= " ++ show v ++ " in environment " ++ show rho
    subtype v2principal v

inferExpr :: Expr -> TypeCheck TVal 
inferExpr e = enter ("inferExpr " ++ show e) $
    (case e of
      Var x -> -- traceCheck ("infer variable " ++ x) $ 
               do item <- lookupName x
                  if erased (decor item) then 
                    throwErrorMsg $ "inferExpr: erased variable " ++ x ++ " : " ++ show (typ item) ++ " may not occur!"
                   else do traceCheckM ("infer variable " ++ x ++ " : " ++ show  (typ item))  
                           return $ typ item
      Set -> return VSet -- TYPE:TYPE !!
      Size -> return VSet
      Infty -> return VSize
      Sing e1 t -> do
        tv <- whnf' t
        checkExpr e1 tv
        return VSet
      App e1 [e2] ->
          do
            v <- inferExpr e1
            case v of
               VPi dec x av env b -> do
                  v2 <- if inferable e2 then do
                  -- if e2 has a singleton type, we should not take v2 = whnf e2
                  -- but use the single value of e2
                  -- this is against the spirit of bidir. checking
                           -- if checking a type we need to resurrect
                           av' <- maybeResurrectDec dec av $ inferExpr e2
                           case av' of
                              VSing v2 av'' -> do subtype av' av
                                                  return v2
                              _ -> do checkSubtype e2 av' av
                                      whnf' e2
                         else do
                           checkExprDec dec e2 av
                           whnf' e2
                  whnf (update env x v2) b  
               _ -> throwErrorMsg $ "inferExpr : expected Pi with expression : " ++ show e1 ++ "," ++ show v
 
      App e1 (e2:el) -> inferExpr $ (e1 `App` [e2]) `App` el  
      (Def n) -> -- traceCheck ("infer defined head " ++ n) $
                 do sig <- gets signature 
                    case (lookupSig n sig) of
                      (DataSig { symbTyp = tv }) -> return tv
                      (FunSig  { symbTyp = tv }) -> return tv
      (Con _ n) -> do sig <- gets signature
                      case (lookupSig n sig) of
                        (ConSig tv) -> return tv
      (Let n) -> do sig <- gets signature 
                    case (lookupSig n sig) of
                      (LetSig tv _) -> return tv
      _ -> throwErrorMsg $ "cannot infer type of " ++ show e
     ) -- >>= \ tv -> traceCheck ("inferExpr: " ++ show e ++ " :=> " ++ show tv) $ return tv

-- entry point 3: resurrects
checkType :: Expr -> TypeCheck ()
checkType e = (resurrect $ checkType' e) `throwTrace` ("not a type: " ++ show e )

checkType' :: Expr -> TypeCheck ()
checkType' e = case e of
    Set -> return ()
    Size -> return ()
    Pi dec x t1 t2 -> do
        checkType' t1
        -- ignore erasure flag in types!
        addBind x (Dec False) t1 $ 
          checkType' t2  
    _ -> checkExpr' e VSet


-- small type
checkSType :: Expr -> TypeCheck ()
checkSType e  = (checkExpr e VSet) `throwTrace` ("not a set: " ++ show e )

 
-- the integer argument is the number of the clause, used just for user feedback
checkCases :: Val -> TVal -> [Clause] -> TypeCheck ()
checkCases = checkCases' 1

checkCases' :: Int -> Val -> TVal -> [Clause] -> TypeCheck ()
checkCases' i v tv [] = return ()
checkCases' i v tv (c:cl) = do 
    c'  <- checkCase i v tv c
    cl' <- checkCases' (i + 1) v tv cl
    return $ () -- c' : cl'

checkCase :: Int -> Val -> TVal -> Clause -> TypeCheck ()
checkCase i v tv (Clause [p] rhs) =
  traceCheck ("checking case " ++ show i) $
    (
    do   
      (flex,ins,cxt,vt) <- checkPattern [] [] tv p
      local (\ _ -> cxt) $ do
        -- mapM (checkDot ins) flex
        vp <- whnf' (patternToExpr p)
--        vp <- patternToVal p -- BUG: INTRODUCES FRESH GENS, BUT THEY HAVE ALREADY BEEN INTRODUCED IN checkPattern
        addRewrite (Rewrite v vp) [vt] $ \ [vt'] -> do
          checkRHS rhs vt'
          -- rhs' <- solveAndModify rhs (environ cxt)
          -- return (Clause [p] rhs')
    ) `throwTrace` ("case " ++ show i)

-- type check a function

checkFun :: Type -> [Clause] -> TypeCheck [Clause]
checkFun t cl = do
  tv <- whnf [] t
  checkClauses tv cl
 
-- the integer argument is the number of the clause, used just for user feedback
checkClauses :: TVal -> [Clause] -> TypeCheck [Clause]
checkClauses = checkClauses' 1

checkClauses' :: Int -> TVal -> [Clause] -> TypeCheck [Clause]
checkClauses' i tv [] = return []
checkClauses' i tv (c:cl) = do 
    c'  <- checkClause i tv c
    cl' <- checkClauses' (i + 1) tv cl
    return $ c' : cl'

-- checking one equation of a function
-- solve size constraints
-- substitute solution into clause
checkClause :: Int -> TVal -> Clause -> TypeCheck Clause
checkClause i v (Clause pl rhs) =
  -- traceCheck ("checking function clause " ++ show i) $
    (
    do   
      (flex,ins,cxt,vt) <- checkPatterns [] [] v pl
      local (\ _ -> cxt) $ do
        mapM (checkDot ins) flex
        checkRHS rhs vt
        rhs' <- solveAndModify rhs (environ cxt)
        return (Clause pl rhs')
    ) `throwTrace` ("clause " ++ show i)



type Substitution = [(Int,TVal)]

type DotFlex = (Int,(Expr,Domain))

-- checkPatterns is initially called with an empty local context
-- in the type checking monad
checkPatterns :: [DotFlex] -> Substitution -> TVal -> [Pattern] -> TypeCheck ([DotFlex],Substitution,TCContext,TVal)
checkPatterns flex ins v pl = 
    case pl of
      [] -> do cxt <- ask
               return (flex,ins,cxt,v)
      (p:pl') -> do (flex',ins',cxt',v') <- checkPattern flex ins v p 
                    local (\ _ -> cxt') $ checkPatterns flex' ins' v' pl' 
       
{- 
checkPattern flex subst v p = (flex', subst', cxt', v')

Input : 
  flex  : list of pairs (flexible variable, its dot pattern + supposed type)
  subst : list of pairs (flexible variable, its valuation)
  cxt   : in monad, containing
    rho   : binding of variables to values
    delta : binding of generic values to their types
  v     : type of the expression \ p -> t
  p     : the pattern to check

Output
  v'    : type of t
-}

checkPattern :: [DotFlex] -> Substitution -> TVal -> Pattern -> TypeCheck ([DotFlex],Substitution,TCContext,TVal)
checkPattern flex ins v p = -- ask >>= \ TCContext { context = delta, environ = rho } -> traceCheck ("checkPattern" ++ ("\n  dot pats: " +?+ show flex) ++ ("\n  substion: " +?+ show ins) ++ ("\n  environ : " +?+ show rho) ++ ("\n  context : " +?+ show delta) ++ "\n  pattern : " ++ show p ++ "\n  at type : " ++ show v ++ "\t<>") $ 
 (
 do 
  case v of
    VPi dec x av env b -> do
       case p of
          VarP y -> new y (Domain av dec) $ \ xv -> do
                       bv <- whnf (update env x xv) b
                       cxt' <- ask 
                       return (flex, ins, cxt', bv)
          ConP co n pl -> do
-- TODO: ensure that matchings against erased arguments are forced 
--                 when (erased dec) $ throwErrorMsg $ "checkPattern: cannot match on erased argument " ++ show p ++ " : " ++ show av 
                 sig <- gets signature 
                 cxt <- ask
                 let (ConSig vc) = (lookupSig n sig)
                 (flex',ins',cxt',vc') <- checkPatterns flex ins vc pl
                 let flexgen = fst $ unzip flex'
--                  av1 <- sing (environ cxt') (patternToExpr p) vc' 
--                  av2 <- sing (environ cxt') (patternToExpr p) av 
--                  subst <- local (\ _ -> cxt') $ inst flexgen VSet av1 av2

                 pv0 <- patternToVal p -- THIS USE should be ok, since the new GENs are not in the global context yet, only in cxt'
                 subst <- local (\ _ -> cxt') $ do
                   case av of
                     VSing vav av0 -> inst flexgen av0 pv0 vav
                     _ -> inst flexgen VSet vc' av

{-
                 ins'' <- compSubst ins' subst
                 vb <- substVal ins'' vb
                 delta' <- substCxt ins'' delta'
-}
                 ins''   <- compSubst ins' subst
                 delta'' <- substCxt ins'' (context cxt')
                 pv  <- up pv0 av
                 vb  <- whnf (update env x pv) b
                 vb' <- substVal ins'' vb  -- ?? why not first subst and then whnf?
                 -- traceCheck ("Returning type " ++ show vb') $
                 return (flex',ins'', cxt' { context = delta''},vb')

          SuccP p2 -> do  
                 when (erased dec) $ throwErrorMsg $ "checkPattern: cannot match on erased argument " ++ show p ++ " : " ++ show av 
                 cxt <- ask
                 (flex',ins',cxt',v') <- checkPattern flex ins (VSize `arrow` VSize) p2
                 when (av /= VSize) (throwErrorMsg "checkPattern: expected type Size") 
                 -- leqVal NSPos delta' VSet VSize av -- av = VSize 
                 pv0 <- patternToVal p
                 pv  <- up pv0 av
                 vb  <- whnf (update env x pv) b
                 return (flex',ins',cxt',vb)
          DotP e -> newWithGen "" (Domain av dec) $ \ k v -> do
                       vb <- whnf (update env x v) b
                       cxt' <- ask
                       -- traceCheck ("Returning type " ++ show vb) $
                       return ((k,(e,Domain av dec)):flex
                              ,ins
                              ,cxt'
                              ,vb)
{- original code 
                    do let (k, delta') = cxtPush dec av delta
                       vb <- whnf (update env x (VGen k)) b
                       return ((k,(e,Domain av dec)):flex
                              ,ins
                              ,rho
                              ,delta'
                              ,vb)
-}
    _ -> throwErrorMsg $ "checkpattern " ++ show v
  ) `throwTrace` ("pattern " ++ show p)
 


checkDot :: Substitution -> DotFlex -> TypeCheck ()
checkDot subst (i,(e,it)) = 
       (
       case (lookup i subst) of
         Nothing -> throwErrorMsg $ "not instantiated "
         Just v -> do tv <- substVal subst (typ it)
{-
                      ce <- ask
                      traceCheck ("checking dot pattern " ++ show ce ++ " |- " ++ show e ++ " : " ++ show tv) $ 
 -}
                      (if erased (decor it) then resurrect else id) $ do
                         checkExpr e tv
                         v' <-  whnf' e
                         eqVal tv v v'
       ) `throwTrace` ("dot pattern " ++ show e)

checkRHS :: Expr -> TVal -> TypeCheck ()
checkRHS rhs v = traceCheck ("checking rhs " ++ show rhs ++ " : " ++ show v) $ 
                     (
                      checkExpr rhs v  
                     ) `throwTrace` "right hand side"


  
-- TODO type directed unification

-- match v1 against v2 by unification , yielding a substition
inst :: [Int] -> TVal -> Val -> Val -> TypeCheck Substitution
inst flex tv v1 v2 = {- ask >>= \ cxt -> traceCheck ("inst " ++ show (context cxt) ++ " |- " ++ show v1 ++ " =?= " ++ show v2 ++ " : " ++ show tv) $ do -}
--  case tv of
--    (VPi dec x av env b) -> 
  case (v1,v2) of
    (VGen k,_) | elem k flex -> do
                       l <- getLen
                       noc <- nocc l v1 v2 
                       case noc of 
                         True -> return [(k,v2)]
                         False -> throwErrorMsg "occurs check failed"
    (_,VGen k) | elem k flex -> do
                   l <- getLen
                   noc <- nocc l v2 v1 
                   case noc of 
                         True -> return [(k,v1)]
                         False -> throwErrorMsg "occurs check failed"
    (VApp (VDef d1) vl1,VApp (VDef d2) vl2) | d1 == d2 ->  do
         sig <- gets signature 
         instList flex (symbTyp (lookupSig d1 sig)) vl1 vl2
    (VApp (VCon _ c1) vl1,VApp (VCon _ c2) vl2) | c1 == c2 -> do
         sig <- gets signature  
         instList flex (symbTyp (lookupSig c1 sig)) vl1 vl2
    (VSucc v1',VSucc v2') -> inst flex tv v1' v2'
    (VSucc v, VInfty) -> inst flex tv v VInfty
    (VSing v1' tv1, VSing v2' tv2) -> do 
      subst <- inst flex tv tv1 tv2
      u1 <- substVal subst v1'
      u2 <- substVal subst v2'
      tv1' <- substVal subst tv1
      inst flex tv1' u1 u2 >>= compSubst subst
      
-- HACK AHEAD
    (VUp v1 _, _) -> inst flex tv v1 v2
    (_, VUp v2 _) -> inst flex tv v1 v2
--    (VUp v1' a1, VUp v2' a2) -> instList flex [a1,v1'] [a2,v2']
--     (VPi dec x1 av1 env1 b1, VPi dec x2 av2 env2 b2) ->
      
{- TODO: REPAIR THIS
    _ -> traceCheck ("inst: WARNING! assuming " ++ show (context cxt) ++ " |- " ++ show v1 ++ " == " ++ show v2) $
           return [] -- throwErrorMsg $ "inst: NYI"
 -}   
    _ -> do eqVal tv v1 v2 `throwTrace` ("inst: eqVal " ++ show v1 ++ " =?= " ++ show v2 ++ " : " ++ show tv ++ " failed")
            return []

instList :: [Int] -> TVal -> [Val] -> [Val] -> TypeCheck Substitution
instList flex tv [] [] = return []
instList flex tv (v1:vl1) (v2:vl2) = 
  case tv of
    (VPi dec x av env b) -> do    
      subst <- inst flex av v1 v2
      vl1' <- mapM (substVal subst) vl1
      vl2' <- mapM (substVal subst) vl2
      v    <- substVal subst v1
      env' <- substEnv subst env
      vb   <- whnf (update env' x v) b
      subst' <- instList flex vb vl1' vl2'
      compSubst subst subst'

{-
-- match v1 against v2 by unification , yielding a substition
inst :: [Int] -> Val -> Val -> TypeCheck Substitution
inst flex v1 v2 = ask >>= \ cxt -> traceCheck ("inst " ++ show (context cxt) ++ " |- " ++ show v1 ++ " =?= " ++ show v2) $ do
  case (v1,v2) of
    (VGen k,_) | elem k flex -> do
                       l <- getLen
                       noc <- nocc l v1 v2 
                       case noc of 
                         True -> return [(k,v2)]
                         False -> throwErrorMsg "occurs check failed"
    (_,VGen k) | elem k flex -> do
                   l <- getLen
                   noc <- nocc l v2 v1 
                   case noc of 
                         True -> return [(k,v1)]
                         False -> throwErrorMsg "occurs check failed"
    (VApp (VDef d1) vl1,VApp (VDef d2) vl2) | d1 == d2 -> 
                   instList flex vl1 vl2
    (VApp (VCon _ c1) vl1,VApp (VCon _ c2) vl2) | c1 == c2 -> 
            instList flex vl1 vl2
    (VSucc v1',VSucc v2') -> inst flex v1' v2'
    (VSucc v, VInfty) -> inst flex v VInfty
-- HACK AHEAD
    (VUp v1 _, _) -> inst flex v1 v2
    (_, VUp v2 _) -> inst flex v1 v2
--    (VUp v1' a1, VUp v2' a2) -> instList flex [a1,v1'] [a2,v2']
--     (VPi dec x1 av1 env1 b1, VPi dec x2 av2 env2 b2) ->
      
    _ -> traceCheck ("inst: WARNING! assuming " ++ show (context cxt) ++ " |- " ++ show v1 ++ " == " ++ show v2) $
           return [] -- throwErrorMsg $ "inst: NYI"
{- TODO: REPAIR THIS
    _ -> do eqVal delta v1 v2
            return []
 -}   

instList :: [Int] -> [Val] -> [Val] -> TypeCheck Substitution
instList flex [] [] = return []
instList flex (v1:vl1) (v2:vl2) = do 
  subst <- inst flex v1 v2
  vl1' <- mapM (substVal subst) vl1
  vl2' <- mapM (substVal subst) vl2
  subst' <- instList flex vl1' vl2'
  compSubst subst subst'
-}

-- substitute generic variable in value
substVal :: Substitution -> Val -> TypeCheck Val
substVal subst v =  
    case v of
      VGen k -> case lookup k subst of
                  Nothing ->  return $ v
                  Just v' ->  return $ v'
      VApp v1 vl -> do v1' <- substVal subst v1
                       vl' <- mapM (substVal subst) vl
                       app v1' vl' 
      VSing v1 vt -> do v1' <- substVal subst v1
                        vt' <- substVal subst vt
                        reSing v1' vt'  -- TODO: Check reevaluation necessary? 
      VSucc v1 -> do v1' <- substVal subst v1
                     return $ succSize v1'
      VCase v1 env cl -> do v1' <- substVal subst v1
                            env' <- substEnv subst env
                            return $ VCase v1' env' cl
      VPi dec x av env b ->  
          do av'  <- substVal subst av
             env' <- substEnv subst env
             return $ VPi dec x av' env' b
      VLam x env b -> do env' <- substEnv subst env
                         return $ VLam x env' b
      VUp v1 vt -> do v1' <- substVal subst v1
                      vt' <- substVal subst vt
                      up v1' vt'
      VSet      -> return $ VSet
      VSize     -> return $ VSize
      VInfty    -> return $ VInfty
      VIrr      -> return $ VIrr
      VDef n    -> return $ VDef n
      VCon co n -> return $ VCon co n
      VMeta x n -> return $ VMeta x n


substCxt :: Substitution -> SemCxt -> TypeCheck SemCxt
substCxt subst delta = do  cxt' <- mapMapM (substVal subst) (cxt delta)
                           return $ delta { cxt = cxt' }

-- substitute in environment
substEnv :: Substitution -> Env -> TypeCheck Env
substEnv subst [] = return $ []
substEnv subst ((x,v):env) = do  v'   <- substVal subst v
                                 env' <- substEnv subst env
                                 return $  (x,v'):env'



-- "merge" substitutions by first applying the second to the first, then 
-- appending them
compSubst :: Substitution -> Substitution -> TypeCheck Substitution
compSubst subst1 subst2 = do
    let (dom1,tg1) = unzip subst1
    tg1' <- mapM (substVal subst2) tg1
    let subst1' = zip dom1 tg1'
    return $ subst1' ++ subst2               

{-
-- substitute generic variable in value
substVal :: Substitution -> Val -> TypeCheck Val
substVal map v =  
  do
    case v of
      VGen k -> case lookup k map of
                  Nothing -> return v
                  Just v' -> return v'
      VApp v1 vl -> do v1' <- substVal map v1
                       vl' <- mapM (substVal map) vl
                       return $ VApp v1' vl'
      VSucc v1 -> do v1' <- substVal map v1
                     return $ succSize v1'
      VPi dec x av env b -> do 
         av' <- substVal map av
         env' <- substEnv map env
         return $ VPi dec x av' env' b
      VLam x env b -> do env' <- substEnv map env
                         return $ VLam x env' b
      _ -> return v

substCxt :: Substitution -> SemCxt -> TypeCheck SemCxt
substCxt subst delta = do cxt' <- mapM (substVal subst) (Map.toList (cxt delta))
                          return $ delta { cxt = cxt' }

-- substitute in environment
substEnv :: Substitution -> Env -> TypeCheck Env
substEnv map [] = return []
substEnv map ((x,v):env) = do v' <- substVal map v
                              env' <- substEnv map env
                              return $ (x,v'):env'



-- "merge" substitutions by first applying the second to the first, then 
-- appending them
compSubst :: Substitution -> Substitution -> TypeCheck Substitution
compSubst subst1 subst2 =
    do let (dom1,tg1) = unzip subst1
       tg1' <- mapM (substVal subst2) tg1
       let subst1' = zip dom1 tg1'
       return $ subst1' ++ subst2               
-}

---- Size checking
--------------

-- check wether the data type is sized type


-- check data declaration type 
-- called from typeCheckDeclaration (DataDecl{})
-- parameters : number of params, type 
szType :: Int -> TVal -> TypeCheck ()
szType p tv = do (tv',k) <- doVParams p 0 tv
                 case tv' of
                   VPi dec x av env b -> do
                      case av of
                         VSize -> return ()
                         _ -> throwErrorMsg "not a sized type"
                   _ -> throwErrorMsg "not a sized type"
                 
-- check data constructors
-- called from typeCheckDeclaration (DataDecl{})
szConstructor :: Name -> Co -> Int -> TVal -> TypeCheck ()
szConstructor n co p tv = do 
    let err = throwErrorMsg "not a valid sized constructor"
    (tv',k) <- doVParams p 0 tv
    case tv' of
       VPi dec x av env b -> do
                case av of
                  VSize -> do bv <- whnf (update env x (VGen k)) b 
                              b <- szSizeVarUsage n (k+1) co p k bv
                              case b of 
                                True -> return ()
                                False -> err
                  _ -> err
       _ -> err

szSizeVarUsage :: Name -> Int -> Co -> Int -> Int -> TVal -> TypeCheck Bool 
szSizeVarUsage n k co p i tv = 
    case tv of
       VPi dec x av env b -> liftM and $ mapM id $
                [ szSizeVarDataArgs n k p i av  -- recursive calls of for D..i..
                , szMono co i av                -- monotone in i
                , do bv <- whnf (update env x (VGen k)) b
                     szSizeVarUsage n (k+1) co p i bv
                ]
       _ -> szSizeVarTarget k p i tv

-- check that Target is of form D ... (Succ i) ... 
szSizeVarTarget :: Int -> Int -> Int -> TVal -> TypeCheck Bool
szSizeVarTarget k p i tv = 
    case tv of
       (VApp d vl) -> do
               let v0 = (vl !! p)
               case v0 of
                 (VSucc (VGen i')) | i == i' -> return True
                 _ -> return False
       _ -> return False 


-- check that rec. arguments are of form D ... i ....
-- and size used nowhere else ?? -- Andreas, 2009-11-27 TOO STRICT!
{- accepts, for instance

   Nat -> Ord i      as argument of a constructor of  Ord ($ i)
   List (Rose A i)   as argument of a constructor of  Rose A ($i)
 -}
szSizeVarDataArgs :: Name -> Int -> Int -> Int -> TVal -> TypeCheck Bool
szSizeVarDataArgs n k p i tv = do
   case tv of
     
     {- case D pars sizeArg args -} 
     VApp (VDef m) vl | n == m -> do 
        let v0 = vl !! p
        case v0 of
          (VGen i') -> case i' == i of
                             True -> do let rargs = take p vl ++ drop (p+1) vl
                                        bl <- mapM (nocc k (VGen i) ) rargs
                                        return $ and bl
                             False -> return False
          _ -> return False

-- not necessary: check for monotonicity above
--     {- case D' pars sizeArg args -}
--     VApp (VDef m) vl | n /= m -> do 

     VApp v1 vl ->  do b <- szSizeVarDataArgs n k p i v1
                       bl <- mapM (szSizeVarDataArgs n k p i) vl
                       return $ b && and bl
     VPi dec x av env b -> do 
              let k' = k + 1
              bv <- whnf (update env x (VGen k)) b
              b1 <- szSizeVarDataArgs n k' p i av
              b2 <- szSizeVarDataArgs n k' p i bv
              return $ b1 && b2

     VLam x env b -> do
              let k' = k + 1
              bv <- whnf (update env x (VGen k)) b
              szSizeVarDataArgs n k' p i bv           
     _ -> return True

{- REMOVED, 2009-11-28, replaced by monotonicity check
     VGen i' -> return $ i' /= i
     VSucc tv' -> szSizeVarDataArgs n k p i tv'
 -}

doVParams :: Int -> Int -> TVal -> TypeCheck (TVal,Int)
doVParams 0 k tv = do return (tv,k)
doVParams p k (VPi dec x av env b) = do 
  bv <- whnf (update env x (VGen k)) b
  doVParams (p - 1 ) (k + 1) bv

--------------------------------------
-- check for admissible  type

{- 

 - admissibility needs to be check clausewise, because of Karl's example

   fun nonAdmissibleType : Unit -> Set

   fun diverge : (u : Unit) -> nonAdmissibleType u
   {
     diverge unit patterns = badRhs
   }
   
 - the type must be admissible in the current position 
   only if the size pattern is a successor.  
   If the pattern is a variable, then there is no induction on that size
   argument, so no limit case, so no upper semi-continuity necessary
   for the type.

 - when checking

     ... (s i) ps  admissible  (j : Size) -> A

   we will check
  
     A  admissible in j

   and continue with

     ... ps  admissible  A[s i / j]

   just to maintain type wellformedness.  The (s i) in A does not
   really matter, since there is no case distinction on ordinals.

 - a size pattern which is not inductive (meaning there is an
    inductive type indexed by that size) nor coinductive (meaning that
    the result type is coinductive and is indexed by that size) must
    be flagged unusable for termination checking.  

 - the fun/cofun distinction could be inferred by the termination checker
   or be clausewise as in Agda 2

-}


admFunDef :: Co -> [Clause] -> TVal -> TypeCheck [Clause]
admFunDef co cls tv = do
  (cls, inco) <- admClauses cls tv
  when (co==CoInd && not (co `elem` inco)) $ 
    fail $ show tv ++ " is not a type of a cofun" -- ++ if co==Ind then "fun" else "cofun"
  return cls 

admClauses :: [Clause] -> TVal -> TypeCheck ([Clause], [Co])
admClauses [] tv = return ([], [])
admClauses (cl:cls) tv = do
  (cl',inco) <- admClause cl tv
  (cls',inco') <- admClauses cls tv
  return (cl' : cls', inco ++ inco')

admClause :: Clause -> TVal -> TypeCheck (Clause, [Co])
admClause (Clause ps e) tv = -- traceCheck ("admClause: admissibility of patterns " ++ show ps) $
   introPatVars ps $ do 
     vs <- mapM (whnf' . patternToExpr) ps
     let pvs = zip ps vs
     introPatTypes pvs tv $ \ _ -> do
       (ps', inco) <- admPatterns pvs tv
       return (Clause ps' e, inco)

admPatterns :: [(Pattern,Val)] -> TVal -> TypeCheck ([Pattern], [Co])
admPatterns [] tv = do
  isCo <- endsInCo tv
  return ([], if isCo then [CoInd] else [])
admPatterns ((p,v):pvs) tv = do
   (p, inco1)  <- admPattern p tv
   bv <- piApp tv v
   (ps, inco2) <- admPatterns pvs bv
   return (p:ps, inco1 ++ inco2)



-- introduce variables bound in pattern into the environment
-- extend delta by generic values but do not introduce their types
introPatVar :: Pattern -> TypeCheck a -> TypeCheck a
introPatVar p cont = 
    case p of
      VarP n -> addName n $ \ _ -> cont 
      ConP co n pl -> introPatVars pl cont
      SuccP p -> introPatVar p cont
      DotP e -> cont

introPatVars :: [Pattern] -> TypeCheck a -> TypeCheck a
introPatVars [] cont = cont
introPatVars (p:ps) cont = introPatVar p $ introPatVars ps $ cont

-- if the bindings name->gen are already in the environment
-- we can now bind the gen to their types
introPatType :: (Pattern,Val) -> TVal -> (TVal -> TypeCheck a) -> TypeCheck a
introPatType (p,v) tv f = 
  case tv of
    VPi dec x av env b -> do
       bv <- whnf (update env x v) b
       matchPatType (p,v) av $ f bv

introPatTypes :: [(Pattern,Val)] -> TVal -> (TVal -> TypeCheck a) -> TypeCheck a
introPatTypes pvs tv f = do
  case pvs of
    [] -> f tv
    (pv:pvs') -> introPatType pv tv $ \ tv' -> introPatTypes pvs' tv' f

matchPatType :: (Pattern, Val) -> TVal -> TypeCheck a -> TypeCheck a
matchPatType (p,v) av cont = 
       case (p,v) of
                                                   -- erasure does not matter!
          (VarP y, VGen k) -> setType k (Domain av (Dec False)) $ cont

          (ConP co n [], _) -> cont

          (ConP co n pl, VApp (VCon{}) vl) -> do
             sig <- gets signature 
             let (ConSig vc) = lookupSig n sig
             introPatTypes (zip pl vl) vc $ \ _ -> cont
 
          (SuccP p2, VSucc v2) -> matchPatType (p2, v2) VSize $ cont 

          (DotP e, _) -> cont
          
          _ -> fail $ "matchPatType: IMPOSSIBLE " ++ show (p,v)

{-
-- turn a pattern into a value
-- extend delta by generic values but do not introduce their types
evalPat :: Pattern -> (Val -> TypeCheck a) -> TypeCheck a
evalPat p f = 
    case p of
      VarP n -> addName n f 
      ConP co n [] -> f (VCon co n)
      ConP co n pl -> evalPats pl $ \ vl -> f (VApp (VCon co n) vl)
      SuccP p -> evalPat p $ \ v -> f (VSucc v)
-- DOES NOT WORK SINCE e has unbound variables
      DotP e -> do
        v <- whnf' e
        f v

evalPats :: [Pattern] -> ([Val] -> TypeCheck a) -> TypeCheck a
evalPats [] f = f []
evalPats (p:ps) f = evalPat p $ \ v -> evalPats ps $ \ vs -> f (v:vs) 
-}

{-
evalPat :: Pattern -> TypeCheck (State TCContext Val)
evalPat p = 
    case p of
      VarP n -> return $ State $ \ ce ->
        let (k, delta) = cxtPushGen (context ce)
            rho = update n (VGen k) (environ ce)
        in  (VGen k, TCContext { context = delta, environ = rho })
      ConP co n [] -> return (VCon co n)
      ConP co n pl -> do
        vl <- mapM evalPat pl 
        return (VApp (VCon co n) vl)
      SuccP p -> do
       v <- evalPat p
       return (VSucc v)   
-- TODO: does not work!
--      DotP e -> return $ State $ \ ce ->
-}     
         

endsInCo :: TVal -> TypeCheck Bool
endsInCo tv  = -- traceCheck ("endsInCo: " ++ show tv) $
   case tv of
      VPi dec x av env b -> new x (Domain av dec) $ \ gen -> do
         bv <- whnf (update env x gen) b
         endsInCo  bv

      -- if not applied, it cannot be a sized type
      VDef n -> do 
         sig <- gets signature
         case (lookupSig n sig) of
            DataSig { isCo = CoInd } -> -- traceCheck ("found non-sized coinductive target") $ 
               return True
            _ -> return False

      VApp (VDef n) vl -> do 
         sig <- gets signature
         case (lookupSig n sig) of
            DataSig { isCo = CoInd } -> -- traceCheck ("found non-sized coinductive target") $ 
               return True
            _ -> return False
      _ -> return False

-- precondition: Pattern does not contain "Unusable"
admPattern :: Pattern -> TVal -> TypeCheck (Pattern, [Co])
admPattern p tv = -- traceCheck ("admPattern " ++ show p ++ " type: " ++ show tv) $
  case tv of
      VPi dec x av env b -> newWithGen x (Domain av dec) $ \ k xv -> do
         bv <- whnf (update env x xv) b
  {-
         if p is successor pattern
         check that bv is admissible in k, returning subset of [Ind, CoInd]       
         p is usable if either CoInd or it is a var or dot pattern and Ind  
-}
         if isSuccessorPattern p then do
           inco <- admType k bv
           when (CoInd `elem` inco && not (shallowSuccP p)) $
             fail ("cannot match coinductive size against deep successor pattern " 
                    ++ show p ++ "; type: " ++ show tv)
           if (CoInd `elem` inco)
              || (inco /= [] && completeP p) 
            then return (p, inco)
            else return (UnusableP p, inco)
          else return (p, [])

      _ -> fail "admPattern: IMPOSSIBLE: pattern for a non-function type"

admType :: Int -> TVal -> TypeCheck [Co]
admType i tv = -- traceCheck ("admType: " ++ show tv ++ " admissible in v" ++ show i) $
    case tv of 
       VPi dec x av env b -> do
          isInd <- szUsed Ind i av
          when (not isInd) $
            szAntitone i av `newErrorMsg` 
             ("type " ++ show av ++ " not lower semi continuous in v" ++ show i)  
          new x (Domain av dec) $ \ gen -> do
            bv <- whnf (update env x gen) b
            inco <- admType i bv
            if isInd then return (Ind : inco) else return inco
       _ -> do
          isCoind <- szUsed CoInd  i tv
          if isCoind then return [CoInd]
           else do
            szMonotone i tv
            return []         

szUsed :: Co -> Int -> TVal -> TypeCheck Bool
szUsed co i tv = -- traceCheck ("szUsed: " ++ show tv ++ " " ++ show co ++ " in v" ++ show i) $
    case tv of
         (VApp (VDef n) vl) -> 
             do sig <- gets signature
                case (lookupSig n sig) of
                  DataSig { numPars = p 
                          , isSized = Sized 
                          , isCo = co' } | co == co' && length vl > p -> 
                      -- p is the number of parameters
                      -- it is also the index of the size argument
                      do let s = vl !! p
                         case s of
                           VGen i' | i == i' -> return True
                           _ -> return False
                  _ -> return False
         _ -> return False











-- for inductive fun, and for every size argument i
-- - every argument needs to be either inductive or antitone in i 
-- - the result needs to be monotone in i 

{- szCheckIndFun admpos delta tv

 entry point for admissibility check for recursive functions
 - scans for the first size quantification 
 - passes on to szCheckIndFunSize
 - currently: also continues to look for the next size quantification...
 -}

szCheckIndFun :: [Int] -> TVal -> TypeCheck ()
szCheckIndFun admpos tv = -- traceCheck ("szCheckIndFun: " ++ show delta ++ " |- " ++ show tv ++ " adm?") $
      case tv of 
       VPi dec x av env b -> new x (Domain av dec) $ \ (VGen k) -> do
         bv <- whnf' b
         case av of
           VSize -> do when (k `elem` admpos) $ 
                         szCheckIndFunSize k bv
                       szCheckIndFun admpos bv -- this is for lexicographic induction on sizes, I suppose?  Probably should me more fine grained!  Andreas, 2008-12-01
           _ -> szCheckIndFun admpos bv
       _ -> return ()


{- szCheckIndFunSize delta i tv

 checks whether type tv is admissible for recursion in index i
 - every argument needs to be either inductive or antitone in i 
 - the result needs to be monotone in i  
 -}

szCheckIndFunSize :: Int -> TVal -> TypeCheck ()
szCheckIndFunSize i tv = -- traceCheck ("szCheckIndFunSize: " ++ show delta ++ " |- " ++ show tv ++ " adm(v" ++ show i ++ ")?") $ 
    case tv of 
       VPi dec x av env b -> do
            szLowerSemiCont i av
            new' x (Domain av dec) $ do
              bv <- whnf' b
              szCheckIndFunSize i bv
       _ -> szMonotone i tv

{- szLowerSemiCont

 - check for lower semi-continuity [Abel, CSL 2006]
 - current approximation: inductive type or antitone
 -}
szLowerSemiCont :: Int -> TVal -> TypeCheck ()
szLowerSemiCont i av = -- traceCheck ("szlowerSemiCont: checking " ++ show av ++ " lower semi continuous in v" ++ show i) $
   ((szAntitone i av) `catchError` 
      (\ msg -> -- traceCheck (show msg) $
                   szInductive i av)) 
        `newErrorMsg` ("type " ++ show av ++ " not lower semi continuous in v" ++ show i)  
                                                     

{- checking cofun-types for admissibility

conditions:

1. type must end in coinductive type or in sized coinductive type 
   indexed by just a variable i which has been quantified in the type

2. in the second case, each argument must be inductive or antitone in i
   optimization:
     arguments types before the quantification over i can be ignored
-}

data CoFunType 
  = CoFun             -- yes, but not sized cotermination
  | SizedCoFun Int    -- yes an admissible sized type (the Int specifies the number of the recursive size argument)

{-
design:

admCoFun delta tv : IsCoFunType

   endsInCo delta tv (len delta) id

endsInCo delta tv firstVar jobs : IsCoFunType
   
   traverse tv, gather continutations in jobs, check for CoInd in the end
   
   if tv = (x:A) -> B
      push A on delta
      add the following task to jobs:
        check A for lower semicontinuity in delta
      continue on B

   if tv = Codata^i
      run (jobs i)
      if they return (), return YesSized Int, otherwise No

   if tv = Codata
      return Yes

   otherwise
      return No
 -}

-- {- TODO: FINISH THIS!!

admCoFun :: TVal -> TypeCheck CoFunType
admCoFun tv = do 
  l <- getLen 
  admEndsInCo tv l (\ i -> return ())

admEndsInCo :: TVal -> Int -> (Int -> TypeCheck ()) -> TypeCheck CoFunType
admEndsInCo tv firstVar jobs = -- traceCheck ("admEndsInCo: " ++ show tv) $
   case tv of
      VPi dec x av env b -> do
         l <- getLen
         let jobs' = (addJob l av jobs)
         new' x (Domain av dec) $ do
           bv <- whnf' b
           admEndsInCo bv firstVar jobs' 

      -- if not applied, it cannot be a sized type
      VDef n -> do 
         sig <- gets signature
         case (lookupSig n sig) of
            DataSig { isCo = CoInd } -> -- traceCheck ("found non-sized coinductive target") $ 
               return CoFun
            _ -> throwErrorMsg $ "type of cofun does not end in coinductive type"

      VApp (VDef n) vl -> do 
         sig <- gets signature
         case (lookupSig n sig) of
            DataSig { isSized = NotSized, isCo = CoInd } -> -- traceCheck ("found non-sized coinductive target") $ 
               return CoFun
            DataSig { numPars = p, isSized = Sized, isCo = CoInd } | length vl > p -> -- traceCheck ("found sized coinductive target") $
              do 
               -- p is the number of parameters
               -- it is also the index of the size argument
               let s = vl !! p
               case s of
                  VGen i -> do 
                     jobs i
                     return $ SizedCoFun $ i - firstVar 
                  _ -> throwErrorMsg $ "size argument in result type must be a variable" 
            _ -> throwErrorMsg $ "type of cofun does not end in coinductive type"

addJob :: Int -> TVal -> (Int -> TypeCheck ())
       -> (Int -> TypeCheck ())
addJob l tv jobs recVar = do
  -- is the "recursive" size variable actually in scope?
  jobs recVar
  when (recVar < l) $ szLowerSemiCont recVar tv

-- -}


{- szCheckCoFun  OBSOLETE!!

 entry point for admissibility check for corecursive functions
 - scans for the first size quantification 
 - passes on to szCheckIndFunSize
 - currently: also continues to look for the next size quantification
 - and checks in the end whether the target is a coinductive type


-- STALE COMMENT: for a cofun : arguments nocc i and result coinductive in i 
szCheckCoFun :: SemCxt -> TVal -> TypeCheck ()
szCheckCoFun delta tv = 
      case tv of
       VPi dec x av env b -> do
                let (k, delta') = cxtPush dec av delta 
                bv <- whnf (update env x (VGen k)) b
                case av of
                  VSize -> do szCheckCoFunSize delta' k bv
                              szCheckCoFun delta' bv
                  _ -> szCheckCoFun delta' bv 
       -- result 
       (VApp (VDef n) vl) -> 
          do sig <- gets signature
             case (lookupSig n sig) of
               (DataSig _ _ _ CoInd _) -> 
                   return ()
               _ -> throwErrorMsg $ "cofun doesn't target coinductive type"
       (VDef n)  -> 
          do sig <- gets signature
             case (lookupSig n sig) of
               (DataSig _ _ _ CoInd _) -> 
                   return ()
               _ -> throwErrorMsg $ "cofun doesn't target coinductive type"
       _ -> throwErrorMsg $ "cofun doesn't target coinductive type"

szCheckCoFunSize :: SemCxt -> Int -> TVal -> TypeCheck ()
szCheckCoFunSize delta i tv = -- traceCheck ("szco " ++ show tv) $
      case tv of 
       VPi dec x av env b ->  do  
             let (k, delta') = cxtPush dec av delta 
             bv <- whnf (update env x (VGen k)) b
             szLowerSemiCont delta i av
             szCheckCoFunSize delta' i bv
       -- result must be coinductive
       _ -> szCoInductive delta i tv

-}              

szMono :: Co -> Int -> TVal -> TypeCheck Bool
szMono co i tv = 
  (do case co of
         Ind   -> szMonotone i tv
         CoInd -> szAntitone i tv
      return True
  ) `catchError` (\ _ -> return False)

szMonotone :: Int -> TVal -> TypeCheck ()
szMonotone i tv = -- traceCheck ("szMonotone: " ++ show delta ++ " |- " ++ show tv ++ " mon(v" ++ show i ++ ")?") $
 do
   let si = VSucc (VGen i)
   tv' <- substVal [(i,si)] tv
   leqVal SPos VSet tv tv'
   return ()

szAntitone :: Int -> TVal -> TypeCheck ()
szAntitone i tv = -- traceCheck ("szAntitone: " ++ show delta ++ " |- " ++ show tv ++ " anti(v" ++ show i ++ ")?") $
 do
   let si = VSucc (VGen i)
   tv' <- substVal [(i,si)] tv
   leqVal Neg VSet tv tv'
   return ()

-- checks if tv is a sized inductive type of size i 
szInductive :: Int -> TVal -> TypeCheck ()
szInductive i tv = szUsed' Ind i tv

-- checks if tv is a sized coinductive type of size i 
szCoInductive :: Int -> TVal -> TypeCheck ()
szCoInductive i tv = szUsed' CoInd i tv
            
szUsed' :: Co -> Int -> TVal -> TypeCheck ()
szUsed' co i tv =
    case tv of
         (VApp (VDef n) vl) -> 
             do sig <- gets signature
                case (lookupSig n sig) of
                  DataSig { numPars = p, isSized = Sized, isCo =  co' } | co == co' && length vl > p -> 
                      -- p is the number of parameters
                      -- it is also the index of the size argument
                      do let s = vl !! p
                         case s of
                           VGen i' | i == i' -> return ()
                           _ -> fail $ "expected size variable" 
                  _ -> fail $ "expected (co)inductive sized type"
         _ -> fail $ "expected (co)inductive sized type"

